@@ -70,6 +70,7 @@ module Data.GraphViz.Types.Monadic
        , node
        , node'
          -- ** Edges
+       , NodeList (..)
        , edge
        , (-->)
        , (<->)
@@ -211,18 +212,29 @@ node' = (`node` [])
 -- -----------------------------------------------------------------------------
 -- Edges
 
+-- | A list of nodes to serve as edge end-points.
+class NodeList n nl where
+  toNodeList :: nl -> [n]
+
+instance NodeList n [n] where
+  toNodeList = id
+
+instance NodeList n n where
+  toNodeList = (:[])
+
 -- | Add an edge to the graph.
-edge     :: n -> n -> Attributes -> Dot n
-edge f t = tellStmt . ME . DotEdge f t
+edge     :: (NodeList n f, NodeList n t) => f -> t -> Attributes -> Dot n
+edge fl tl as = mapM_ (tellStmt . ME)
+                      [ DotEdge f t as | f <- toNodeList fl, t <- toNodeList tl ]
 
 -- | Add an edge with no attributes.
-(-->) :: n -> n -> Dot n
+(-->) :: (NodeList n f, NodeList n t) => f -> t -> Dot n
 f --> t = edge f t []
 
 infixr 9 -->
 
 -- | An alias for '-->' to make edges look more undirected.
-(<->) :: n -> n -> Dot n
+(<->) :: (NodeList n f, NodeList n t) => f -> t -> Dot n
 (<->) = (-->)
 
 infixr 9 <->
